"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.bulkMoveCommentByFilter = exports.bulkModerateDraftContent = exports.bulkDeleteComment = exports.bulkHideComment = exports.bulkPublishComment = exports.getCommentThread = exports.listCommentsByResource = exports.countComments = exports.publishComment = exports.hideComment = exports.unmarkComment = exports.markComment = exports.queryComments = exports.moderateDraftContent = exports.deleteComment = exports.updateComment = exports.getComment = exports.createComment = void 0;
const rest_modules_1 = require("@wix/sdk-runtime/rest-modules");
const float_1 = require("@wix/sdk-runtime/transformations/float");
const float_2 = require("@wix/sdk-runtime/transformations/float");
const timestamp_1 = require("@wix/sdk-runtime/transformations/timestamp");
const timestamp_2 = require("@wix/sdk-runtime/transformations/timestamp");
const transform_paths_1 = require("@wix/sdk-runtime/transformations/transform-paths");
const rest_modules_2 = require("@wix/sdk-runtime/rest-modules");
function resolveWixCommentsNgV1CommentsNgUrl(opts) {
    const domainToMappings = {
        'www.wixapis.com': [
            {
                srcPath: '/comments/v1/comments',
                destPath: '/v1/comments',
            },
            {
                srcPath: '/comments/v1/bulk/comments',
                destPath: '/v1/bulk/comments',
            },
        ],
        _: [
            {
                srcPath: '/_api/comments-ng/v1',
                destPath: '/v1',
            },
        ],
        'manage._base_domain_': [
            {
                srcPath: '/_api/comments-ng/v1',
                destPath: '/v1',
            },
        ],
        'www._base_domain_': [
            {
                srcPath: '/_api/comments-ng/v1',
                destPath: '/v1',
            },
        ],
        '*.dev.wix-code.com': [
            {
                srcPath: '/_api/comments-ng',
                destPath: '',
            },
        ],
    };
    return (0, rest_modules_2.resolveUrl)(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_comments_comments';
/**
 * Creates a new comment and publishes it.
 *
 * The `appId`, `contextId`, and `resourceId` are all required and associate the created comment with the specific
 * resource it responds to. See **Integrations** in the Comments introduction for a list of integrated scopes for these fields.
 *
 * If the created comment is a direct response to another comment, the `commentId` of the parent comment should be passed
 * as `parentComment.id` in this comment's request. See **Terminology** in the Comments introduction for additional information on parent comments and replies.
 */
function createComment(payload) {
    function __createComment({ host }) {
        const serializedData = (0, transform_paths_1.transformPaths)(payload, [
            {
                transformFn: timestamp_1.transformSDKTimestampToRESTTimestamp,
                paths: [
                    { path: 'comment.createdDate' },
                    { path: 'comment.updatedDate' },
                    { path: 'comment.commentDate' },
                    { path: 'comment.content.commentDate' },
                    { path: 'comment.content.richContent.metadata.createdTimestamp' },
                    { path: 'comment.content.richContent.metadata.updatedTimestamp' },
                    { path: 'comment.content.attachments.image.urlExpirationDate' },
                    { path: 'comment.content.attachments.video.urlExpirationDate' },
                    {
                        path: 'comment.content.attachments.video.posters.urlExpirationDate',
                    },
                    { path: 'comment.content.attachments.audio.urlExpirationDate' },
                    { path: 'comment.content.attachments.document.urlExpirationDate' },
                    { path: 'comment.draftContent.commentDate' },
                    {
                        path: 'comment.draftContent.richContent.metadata.createdTimestamp',
                    },
                    {
                        path: 'comment.draftContent.richContent.metadata.updatedTimestamp',
                    },
                    { path: 'comment.draftContent.attachments.image.urlExpirationDate' },
                    { path: 'comment.draftContent.attachments.video.urlExpirationDate' },
                    {
                        path: 'comment.draftContent.attachments.video.posters.urlExpirationDate',
                    },
                    { path: 'comment.draftContent.attachments.audio.urlExpirationDate' },
                    {
                        path: 'comment.draftContent.attachments.document.urlExpirationDate',
                    },
                ],
            },
            {
                transformFn: float_1.transformSDKFloatToRESTFloat,
                paths: [
                    {
                        path: 'comment.content.richContent.nodes.galleryData.items.image.media.duration',
                    },
                    {
                        path: 'comment.content.richContent.nodes.galleryData.items.video.media.duration',
                    },
                    {
                        path: 'comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration',
                    },
                    {
                        path: 'comment.content.richContent.nodes.galleryData.options.item.ratio',
                    },
                    {
                        path: 'comment.content.richContent.nodes.imageData.image.duration',
                    },
                    { path: 'comment.content.richContent.nodes.mapData.mapSettings.lat' },
                    { path: 'comment.content.richContent.nodes.mapData.mapSettings.lng' },
                    {
                        path: 'comment.content.richContent.nodes.pollData.poll.image.duration',
                    },
                    {
                        path: 'comment.content.richContent.nodes.pollData.poll.options.image.duration',
                    },
                    {
                        path: 'comment.content.richContent.nodes.pollData.design.poll.background.image.duration',
                    },
                    {
                        path: 'comment.content.richContent.nodes.appEmbedData.image.duration',
                    },
                    {
                        path: 'comment.content.richContent.nodes.videoData.video.duration',
                    },
                    {
                        path: 'comment.content.richContent.nodes.videoData.thumbnail.duration',
                    },
                    {
                        path: 'comment.content.richContent.nodes.audioData.audio.duration',
                    },
                    {
                        path: 'comment.content.richContent.nodes.audioData.coverImage.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.galleryData.items.image.media.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.galleryData.items.video.media.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.galleryData.options.item.ratio',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.imageData.image.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.mapData.mapSettings.lat',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.mapData.mapSettings.lng',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.pollData.poll.image.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.pollData.poll.options.image.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.appEmbedData.image.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.videoData.video.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.videoData.thumbnail.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.audioData.audio.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.audioData.coverImage.duration',
                    },
                ],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.comments.v2.comment',
            method: 'POST',
            methodFqn: 'wix.comments.ng.v1.CommentsNg.CreateComment',
            packageName: PACKAGE_NAME,
            url: resolveWixCommentsNgV1CommentsNgUrl({
                protoPath: '/v1/comments',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'comment.createdDate' },
                        { path: 'comment.updatedDate' },
                        { path: 'comment.commentDate' },
                        { path: 'comment.content.commentDate' },
                        { path: 'comment.content.richContent.metadata.createdTimestamp' },
                        { path: 'comment.content.richContent.metadata.updatedTimestamp' },
                        { path: 'comment.content.attachments.image.urlExpirationDate' },
                        { path: 'comment.content.attachments.video.urlExpirationDate' },
                        {
                            path: 'comment.content.attachments.video.posters.urlExpirationDate',
                        },
                        { path: 'comment.content.attachments.audio.urlExpirationDate' },
                        {
                            path: 'comment.content.attachments.document.urlExpirationDate',
                        },
                        { path: 'comment.draftContent.commentDate' },
                        {
                            path: 'comment.draftContent.richContent.metadata.createdTimestamp',
                        },
                        {
                            path: 'comment.draftContent.richContent.metadata.updatedTimestamp',
                        },
                        {
                            path: 'comment.draftContent.attachments.image.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.video.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.video.posters.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.audio.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.document.urlExpirationDate',
                        },
                    ],
                },
                {
                    transformFn: float_2.transformRESTFloatToSDKFloat,
                    paths: [
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'comment.content.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'comment.content.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.audioData.coverImage.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.audioData.coverImage.duration',
                        },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __createComment;
}
exports.createComment = createComment;
/** Retrieves a comment. */
function getComment(payload) {
    function __getComment({ host }) {
        const metadata = {
            entityFqdn: 'wix.comments.v2.comment',
            method: 'GET',
            methodFqn: 'wix.comments.ng.v1.CommentsNg.GetComment',
            packageName: PACKAGE_NAME,
            url: resolveWixCommentsNgV1CommentsNgUrl({
                protoPath: '/v1/comments/{commentId}',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'comment.createdDate' },
                        { path: 'comment.updatedDate' },
                        { path: 'comment.commentDate' },
                        { path: 'comment.content.commentDate' },
                        { path: 'comment.content.richContent.metadata.createdTimestamp' },
                        { path: 'comment.content.richContent.metadata.updatedTimestamp' },
                        { path: 'comment.content.attachments.image.urlExpirationDate' },
                        { path: 'comment.content.attachments.video.urlExpirationDate' },
                        {
                            path: 'comment.content.attachments.video.posters.urlExpirationDate',
                        },
                        { path: 'comment.content.attachments.audio.urlExpirationDate' },
                        {
                            path: 'comment.content.attachments.document.urlExpirationDate',
                        },
                        { path: 'comment.draftContent.commentDate' },
                        {
                            path: 'comment.draftContent.richContent.metadata.createdTimestamp',
                        },
                        {
                            path: 'comment.draftContent.richContent.metadata.updatedTimestamp',
                        },
                        {
                            path: 'comment.draftContent.attachments.image.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.video.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.video.posters.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.audio.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.document.urlExpirationDate',
                        },
                    ],
                },
                {
                    transformFn: float_2.transformRESTFloatToSDKFloat,
                    paths: [
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'comment.content.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'comment.content.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.audioData.coverImage.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.audioData.coverImage.duration',
                        },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __getComment;
}
exports.getComment = getComment;
/**
 * Updates a comment.
 *
 * Each time the comment is updated, `revision` increments by 1. The current `revision` must be
 * passed when updating the comment. This ensures you're working with the latest comment and
 * prevents unintended overwrites.
 */
function updateComment(payload) {
    function __updateComment({ host }) {
        const serializedData = (0, transform_paths_1.transformPaths)(payload, [
            {
                transformFn: timestamp_1.transformSDKTimestampToRESTTimestamp,
                paths: [
                    { path: 'comment.createdDate' },
                    { path: 'comment.updatedDate' },
                    { path: 'comment.commentDate' },
                    { path: 'comment.content.commentDate' },
                    { path: 'comment.content.richContent.metadata.createdTimestamp' },
                    { path: 'comment.content.richContent.metadata.updatedTimestamp' },
                    { path: 'comment.content.attachments.image.urlExpirationDate' },
                    { path: 'comment.content.attachments.video.urlExpirationDate' },
                    {
                        path: 'comment.content.attachments.video.posters.urlExpirationDate',
                    },
                    { path: 'comment.content.attachments.audio.urlExpirationDate' },
                    { path: 'comment.content.attachments.document.urlExpirationDate' },
                    { path: 'comment.draftContent.commentDate' },
                    {
                        path: 'comment.draftContent.richContent.metadata.createdTimestamp',
                    },
                    {
                        path: 'comment.draftContent.richContent.metadata.updatedTimestamp',
                    },
                    { path: 'comment.draftContent.attachments.image.urlExpirationDate' },
                    { path: 'comment.draftContent.attachments.video.urlExpirationDate' },
                    {
                        path: 'comment.draftContent.attachments.video.posters.urlExpirationDate',
                    },
                    { path: 'comment.draftContent.attachments.audio.urlExpirationDate' },
                    {
                        path: 'comment.draftContent.attachments.document.urlExpirationDate',
                    },
                ],
            },
            {
                transformFn: float_1.transformSDKFloatToRESTFloat,
                paths: [
                    {
                        path: 'comment.content.richContent.nodes.galleryData.items.image.media.duration',
                    },
                    {
                        path: 'comment.content.richContent.nodes.galleryData.items.video.media.duration',
                    },
                    {
                        path: 'comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration',
                    },
                    {
                        path: 'comment.content.richContent.nodes.galleryData.options.item.ratio',
                    },
                    {
                        path: 'comment.content.richContent.nodes.imageData.image.duration',
                    },
                    { path: 'comment.content.richContent.nodes.mapData.mapSettings.lat' },
                    { path: 'comment.content.richContent.nodes.mapData.mapSettings.lng' },
                    {
                        path: 'comment.content.richContent.nodes.pollData.poll.image.duration',
                    },
                    {
                        path: 'comment.content.richContent.nodes.pollData.poll.options.image.duration',
                    },
                    {
                        path: 'comment.content.richContent.nodes.pollData.design.poll.background.image.duration',
                    },
                    {
                        path: 'comment.content.richContent.nodes.appEmbedData.image.duration',
                    },
                    {
                        path: 'comment.content.richContent.nodes.videoData.video.duration',
                    },
                    {
                        path: 'comment.content.richContent.nodes.videoData.thumbnail.duration',
                    },
                    {
                        path: 'comment.content.richContent.nodes.audioData.audio.duration',
                    },
                    {
                        path: 'comment.content.richContent.nodes.audioData.coverImage.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.galleryData.items.image.media.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.galleryData.items.video.media.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.galleryData.options.item.ratio',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.imageData.image.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.mapData.mapSettings.lat',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.mapData.mapSettings.lng',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.pollData.poll.image.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.pollData.poll.options.image.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.appEmbedData.image.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.videoData.video.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.videoData.thumbnail.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.audioData.audio.duration',
                    },
                    {
                        path: 'comment.draftContent.richContent.nodes.audioData.coverImage.duration',
                    },
                ],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.comments.v2.comment',
            method: 'PATCH',
            methodFqn: 'wix.comments.ng.v1.CommentsNg.UpdateComment',
            packageName: PACKAGE_NAME,
            url: resolveWixCommentsNgV1CommentsNgUrl({
                protoPath: '/v1/comments/{comment.id}',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'comment.createdDate' },
                        { path: 'comment.updatedDate' },
                        { path: 'comment.commentDate' },
                        { path: 'comment.content.commentDate' },
                        { path: 'comment.content.richContent.metadata.createdTimestamp' },
                        { path: 'comment.content.richContent.metadata.updatedTimestamp' },
                        { path: 'comment.content.attachments.image.urlExpirationDate' },
                        { path: 'comment.content.attachments.video.urlExpirationDate' },
                        {
                            path: 'comment.content.attachments.video.posters.urlExpirationDate',
                        },
                        { path: 'comment.content.attachments.audio.urlExpirationDate' },
                        {
                            path: 'comment.content.attachments.document.urlExpirationDate',
                        },
                        { path: 'comment.draftContent.commentDate' },
                        {
                            path: 'comment.draftContent.richContent.metadata.createdTimestamp',
                        },
                        {
                            path: 'comment.draftContent.richContent.metadata.updatedTimestamp',
                        },
                        {
                            path: 'comment.draftContent.attachments.image.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.video.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.video.posters.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.audio.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.document.urlExpirationDate',
                        },
                    ],
                },
                {
                    transformFn: float_2.transformRESTFloatToSDKFloat,
                    paths: [
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'comment.content.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'comment.content.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.audioData.coverImage.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.audioData.coverImage.duration',
                        },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __updateComment;
}
exports.updateComment = updateComment;
/**
 * Deletes a comment.
 *
 * This method deletes the `content` of the comment and sets its `status` to `DELETED`.
 */
function deleteComment(payload) {
    function __deleteComment({ host }) {
        const metadata = {
            entityFqdn: 'wix.comments.v2.comment',
            method: 'DELETE',
            methodFqn: 'wix.comments.ng.v1.CommentsNg.DeleteComment',
            packageName: PACKAGE_NAME,
            url: resolveWixCommentsNgV1CommentsNgUrl({
                protoPath: '/v1/comments/{commentId}',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
        };
        return metadata;
    }
    return __deleteComment;
}
exports.deleteComment = deleteComment;
/**
 * Moderates the draft content of a comment.
 *
 * - `APPROVE`: Moves `draftContent` to `content` and updates the comment `status` to `PUBLISHED`.
 * - `REJECT`: Clears `draftContent` if comment `status` is `PUBLISHED` or, if comment `status` is `PENDING` it will keep `draftContent` the same and change `status` to `HIDDEN`.
 */
function moderateDraftContent(payload) {
    function __moderateDraftContent({ host }) {
        const metadata = {
            entityFqdn: 'wix.comments.v2.comment',
            method: 'POST',
            methodFqn: 'wix.comments.ng.v1.CommentsNg.ModerateDraftContent',
            packageName: PACKAGE_NAME,
            url: resolveWixCommentsNgV1CommentsNgUrl({
                protoPath: '/v1/comments/{commentId}/moderate',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'comment.createdDate' },
                        { path: 'comment.updatedDate' },
                        { path: 'comment.commentDate' },
                        { path: 'comment.content.commentDate' },
                        { path: 'comment.content.richContent.metadata.createdTimestamp' },
                        { path: 'comment.content.richContent.metadata.updatedTimestamp' },
                        { path: 'comment.content.attachments.image.urlExpirationDate' },
                        { path: 'comment.content.attachments.video.urlExpirationDate' },
                        {
                            path: 'comment.content.attachments.video.posters.urlExpirationDate',
                        },
                        { path: 'comment.content.attachments.audio.urlExpirationDate' },
                        {
                            path: 'comment.content.attachments.document.urlExpirationDate',
                        },
                        { path: 'comment.draftContent.commentDate' },
                        {
                            path: 'comment.draftContent.richContent.metadata.createdTimestamp',
                        },
                        {
                            path: 'comment.draftContent.richContent.metadata.updatedTimestamp',
                        },
                        {
                            path: 'comment.draftContent.attachments.image.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.video.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.video.posters.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.audio.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.document.urlExpirationDate',
                        },
                    ],
                },
                {
                    transformFn: float_2.transformRESTFloatToSDKFloat,
                    paths: [
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'comment.content.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'comment.content.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.audioData.coverImage.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.audioData.coverImage.duration',
                        },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __moderateDraftContent;
}
exports.moderateDraftContent = moderateDraftContent;
/**
 * Creates a query to retrieve a list of comments.
 *
 * The `queryComments()` function builds a query to retrieve a list of comments and returns a [`CommentsQueryBuilder`](#commentsquerybuilder) object.
 *
 * The returned object contains the query definition, which is typically used to run the query using the [`find()`](#commentsquerybuilder/find) function.
 *
 * You can refine the query by chaining `CommentsQueryBuilder` functions onto the query. `CommentsQueryBuilder` functions enable you to sort, filter, and control the results that `queryComments()` returns.
 *
 * `queryComments()` runs with the following `CommentsQueryBuilder` default that you can override:
 * + `ascending("_id")`
 *
 * The functions that are chained to `queryComments()` are applied in the order they are called. For example, if you apply `ascending("voteSummary.netVoteCount")` and then `ascending("replyCount")`, the results are sorted first by the `"voteSummary.netVoteCount"`, and then, if there are multiple results with the same `"voteSummary.netVoteCount"`, the items are sorted by `"replyCount"`.
 *
 * The following `CommentsQueryBuilder` functions are supported for the `queryComments()` function. For a full description of the comment object, see the object returned for the [`items`](#commentsqueryresult/items) property in [`CommentsQueryResult`](#commentsqueryresult).
 */
function queryComments(payload) {
    function __queryComments({ host }) {
        const metadata = {
            entityFqdn: 'wix.comments.v2.comment',
            method: 'POST',
            methodFqn: 'wix.comments.ng.v1.CommentsNg.QueryComments',
            packageName: PACKAGE_NAME,
            url: resolveWixCommentsNgV1CommentsNgUrl({
                protoPath: '/v1/comments/query-cursor',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'comments.createdDate' },
                        { path: 'comments.updatedDate' },
                        { path: 'comments.commentDate' },
                        { path: 'comments.content.commentDate' },
                        {
                            path: 'comments.content.richContent.metadata.createdTimestamp',
                        },
                        {
                            path: 'comments.content.richContent.metadata.updatedTimestamp',
                        },
                        { path: 'comments.content.attachments.image.urlExpirationDate' },
                        { path: 'comments.content.attachments.video.urlExpirationDate' },
                        {
                            path: 'comments.content.attachments.video.posters.urlExpirationDate',
                        },
                        { path: 'comments.content.attachments.audio.urlExpirationDate' },
                        {
                            path: 'comments.content.attachments.document.urlExpirationDate',
                        },
                        { path: 'comments.draftContent.commentDate' },
                        {
                            path: 'comments.draftContent.richContent.metadata.createdTimestamp',
                        },
                        {
                            path: 'comments.draftContent.richContent.metadata.updatedTimestamp',
                        },
                        {
                            path: 'comments.draftContent.attachments.image.urlExpirationDate',
                        },
                        {
                            path: 'comments.draftContent.attachments.video.urlExpirationDate',
                        },
                        {
                            path: 'comments.draftContent.attachments.video.posters.urlExpirationDate',
                        },
                        {
                            path: 'comments.draftContent.attachments.audio.urlExpirationDate',
                        },
                        {
                            path: 'comments.draftContent.attachments.document.urlExpirationDate',
                        },
                    ],
                },
                {
                    transformFn: float_2.transformRESTFloatToSDKFloat,
                    paths: [
                        {
                            path: 'comments.content.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'comments.content.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'comments.content.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'comments.content.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.audioData.coverImage.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.audioData.coverImage.duration',
                        },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __queryComments;
}
exports.queryComments = queryComments;
/**
 * Sets `marked` to `TRUE` to mark a comment.
 *
 * Call Query Comments to filter for marked comments to then apply customization to.
 * See Sample Flows for an example.
 */
function markComment(payload) {
    function __markComment({ host }) {
        const metadata = {
            entityFqdn: 'wix.comments.v2.comment',
            method: 'PUT',
            methodFqn: 'wix.comments.ng.v1.CommentsNg.MarkComment',
            packageName: PACKAGE_NAME,
            url: resolveWixCommentsNgV1CommentsNgUrl({
                protoPath: '/v1/comments/{commentId}/mark',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'comment.createdDate' },
                        { path: 'comment.updatedDate' },
                        { path: 'comment.commentDate' },
                        { path: 'comment.content.commentDate' },
                        { path: 'comment.content.richContent.metadata.createdTimestamp' },
                        { path: 'comment.content.richContent.metadata.updatedTimestamp' },
                        { path: 'comment.content.attachments.image.urlExpirationDate' },
                        { path: 'comment.content.attachments.video.urlExpirationDate' },
                        {
                            path: 'comment.content.attachments.video.posters.urlExpirationDate',
                        },
                        { path: 'comment.content.attachments.audio.urlExpirationDate' },
                        {
                            path: 'comment.content.attachments.document.urlExpirationDate',
                        },
                        { path: 'comment.draftContent.commentDate' },
                        {
                            path: 'comment.draftContent.richContent.metadata.createdTimestamp',
                        },
                        {
                            path: 'comment.draftContent.richContent.metadata.updatedTimestamp',
                        },
                        {
                            path: 'comment.draftContent.attachments.image.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.video.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.video.posters.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.audio.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.document.urlExpirationDate',
                        },
                    ],
                },
                {
                    transformFn: float_2.transformRESTFloatToSDKFloat,
                    paths: [
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'comment.content.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'comment.content.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.audioData.coverImage.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.audioData.coverImage.duration',
                        },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __markComment;
}
exports.markComment = markComment;
/** Sets `marked` to `FALSE` to unmark a comment. */
function unmarkComment(payload) {
    function __unmarkComment({ host }) {
        const metadata = {
            entityFqdn: 'wix.comments.v2.comment',
            method: 'PUT',
            methodFqn: 'wix.comments.ng.v1.CommentsNg.UnmarkComment',
            packageName: PACKAGE_NAME,
            url: resolveWixCommentsNgV1CommentsNgUrl({
                protoPath: '/v1/comments/{commentId}/unmark',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'comment.createdDate' },
                        { path: 'comment.updatedDate' },
                        { path: 'comment.commentDate' },
                        { path: 'comment.content.commentDate' },
                        { path: 'comment.content.richContent.metadata.createdTimestamp' },
                        { path: 'comment.content.richContent.metadata.updatedTimestamp' },
                        { path: 'comment.content.attachments.image.urlExpirationDate' },
                        { path: 'comment.content.attachments.video.urlExpirationDate' },
                        {
                            path: 'comment.content.attachments.video.posters.urlExpirationDate',
                        },
                        { path: 'comment.content.attachments.audio.urlExpirationDate' },
                        {
                            path: 'comment.content.attachments.document.urlExpirationDate',
                        },
                        { path: 'comment.draftContent.commentDate' },
                        {
                            path: 'comment.draftContent.richContent.metadata.createdTimestamp',
                        },
                        {
                            path: 'comment.draftContent.richContent.metadata.updatedTimestamp',
                        },
                        {
                            path: 'comment.draftContent.attachments.image.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.video.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.video.posters.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.audio.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.document.urlExpirationDate',
                        },
                    ],
                },
                {
                    transformFn: float_2.transformRESTFloatToSDKFloat,
                    paths: [
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'comment.content.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'comment.content.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.audioData.coverImage.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.audioData.coverImage.duration',
                        },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __unmarkComment;
}
exports.unmarkComment = unmarkComment;
/** Hides a comment in a widget. The comment status becomes `HIDDEN`. */
function hideComment(payload) {
    function __hideComment({ host }) {
        const metadata = {
            entityFqdn: 'wix.comments.v2.comment',
            method: 'PUT',
            methodFqn: 'wix.comments.ng.v1.CommentsNg.HideComment',
            packageName: PACKAGE_NAME,
            url: resolveWixCommentsNgV1CommentsNgUrl({
                protoPath: '/v1/comments/{commentId}/hide',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'comment.createdDate' },
                        { path: 'comment.updatedDate' },
                        { path: 'comment.commentDate' },
                        { path: 'comment.content.commentDate' },
                        { path: 'comment.content.richContent.metadata.createdTimestamp' },
                        { path: 'comment.content.richContent.metadata.updatedTimestamp' },
                        { path: 'comment.content.attachments.image.urlExpirationDate' },
                        { path: 'comment.content.attachments.video.urlExpirationDate' },
                        {
                            path: 'comment.content.attachments.video.posters.urlExpirationDate',
                        },
                        { path: 'comment.content.attachments.audio.urlExpirationDate' },
                        {
                            path: 'comment.content.attachments.document.urlExpirationDate',
                        },
                        { path: 'comment.draftContent.commentDate' },
                        {
                            path: 'comment.draftContent.richContent.metadata.createdTimestamp',
                        },
                        {
                            path: 'comment.draftContent.richContent.metadata.updatedTimestamp',
                        },
                        {
                            path: 'comment.draftContent.attachments.image.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.video.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.video.posters.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.audio.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.document.urlExpirationDate',
                        },
                    ],
                },
                {
                    transformFn: float_2.transformRESTFloatToSDKFloat,
                    paths: [
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'comment.content.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'comment.content.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.audioData.coverImage.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.audioData.coverImage.duration',
                        },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __hideComment;
}
exports.hideComment = hideComment;
/**
 * Publishes a comment with the `HIDDEN` status. The comment status becomes `PUBLISHED`.
 *
 * To publish a new comment, call Create Comment.
 */
function publishComment(payload) {
    function __publishComment({ host }) {
        const metadata = {
            entityFqdn: 'wix.comments.v2.comment',
            method: 'PUT',
            methodFqn: 'wix.comments.ng.v1.CommentsNg.PublishComment',
            packageName: PACKAGE_NAME,
            url: resolveWixCommentsNgV1CommentsNgUrl({
                protoPath: '/v1/comments/{commentId}/publish',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'comment.createdDate' },
                        { path: 'comment.updatedDate' },
                        { path: 'comment.commentDate' },
                        { path: 'comment.content.commentDate' },
                        { path: 'comment.content.richContent.metadata.createdTimestamp' },
                        { path: 'comment.content.richContent.metadata.updatedTimestamp' },
                        { path: 'comment.content.attachments.image.urlExpirationDate' },
                        { path: 'comment.content.attachments.video.urlExpirationDate' },
                        {
                            path: 'comment.content.attachments.video.posters.urlExpirationDate',
                        },
                        { path: 'comment.content.attachments.audio.urlExpirationDate' },
                        {
                            path: 'comment.content.attachments.document.urlExpirationDate',
                        },
                        { path: 'comment.draftContent.commentDate' },
                        {
                            path: 'comment.draftContent.richContent.metadata.createdTimestamp',
                        },
                        {
                            path: 'comment.draftContent.richContent.metadata.updatedTimestamp',
                        },
                        {
                            path: 'comment.draftContent.attachments.image.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.video.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.video.posters.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.audio.urlExpirationDate',
                        },
                        {
                            path: 'comment.draftContent.attachments.document.urlExpirationDate',
                        },
                    ],
                },
                {
                    transformFn: float_2.transformRESTFloatToSDKFloat,
                    paths: [
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'comment.content.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'comment.content.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'comment.content.richContent.nodes.audioData.coverImage.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'comment.draftContent.richContent.nodes.audioData.coverImage.duration',
                        },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __publishComment;
}
exports.publishComment = publishComment;
/** Counts comments, given the specified filtering. Comments with the `HIDDEN` status are not included in the response. */
function countComments(payload) {
    function __countComments({ host }) {
        const metadata = {
            entityFqdn: 'wix.comments.v2.comment',
            method: 'POST',
            methodFqn: 'wix.comments.ng.v1.CommentsNg.CountComments',
            packageName: PACKAGE_NAME,
            url: resolveWixCommentsNgV1CommentsNgUrl({
                protoPath: '/v1/comments/count',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __countComments;
}
exports.countComments = countComments;
/** Lists published comments and replies from a specified resource, such as a blog post. */
function listCommentsByResource(payload) {
    function __listCommentsByResource({ host }) {
        const metadata = {
            entityFqdn: 'wix.comments.v2.comment',
            method: 'GET',
            methodFqn: 'wix.comments.ng.v1.CommentsNg.ListCommentsByResource',
            packageName: PACKAGE_NAME,
            url: resolveWixCommentsNgV1CommentsNgUrl({
                protoPath: '/v1/comments/list-by-resource',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'comments.createdDate' },
                        { path: 'comments.updatedDate' },
                        { path: 'comments.commentDate' },
                        { path: 'comments.content.commentDate' },
                        {
                            path: 'comments.content.richContent.metadata.createdTimestamp',
                        },
                        {
                            path: 'comments.content.richContent.metadata.updatedTimestamp',
                        },
                        { path: 'comments.content.attachments.image.urlExpirationDate' },
                        { path: 'comments.content.attachments.video.urlExpirationDate' },
                        {
                            path: 'comments.content.attachments.video.posters.urlExpirationDate',
                        },
                        { path: 'comments.content.attachments.audio.urlExpirationDate' },
                        {
                            path: 'comments.content.attachments.document.urlExpirationDate',
                        },
                        { path: 'comments.draftContent.commentDate' },
                        {
                            path: 'comments.draftContent.richContent.metadata.createdTimestamp',
                        },
                        {
                            path: 'comments.draftContent.richContent.metadata.updatedTimestamp',
                        },
                        {
                            path: 'comments.draftContent.attachments.image.urlExpirationDate',
                        },
                        {
                            path: 'comments.draftContent.attachments.video.urlExpirationDate',
                        },
                        {
                            path: 'comments.draftContent.attachments.video.posters.urlExpirationDate',
                        },
                        {
                            path: 'comments.draftContent.attachments.audio.urlExpirationDate',
                        },
                        {
                            path: 'comments.draftContent.attachments.document.urlExpirationDate',
                        },
                        { path: 'commentReplies.*.replies.createdDate' },
                        { path: 'commentReplies.*.replies.updatedDate' },
                        { path: 'commentReplies.*.replies.commentDate' },
                        { path: 'commentReplies.*.replies.content.commentDate' },
                        {
                            path: 'commentReplies.*.replies.content.richContent.metadata.createdTimestamp',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.metadata.updatedTimestamp',
                        },
                        {
                            path: 'commentReplies.*.replies.content.attachments.image.urlExpirationDate',
                        },
                        {
                            path: 'commentReplies.*.replies.content.attachments.video.urlExpirationDate',
                        },
                        {
                            path: 'commentReplies.*.replies.content.attachments.video.posters.urlExpirationDate',
                        },
                        {
                            path: 'commentReplies.*.replies.content.attachments.audio.urlExpirationDate',
                        },
                        {
                            path: 'commentReplies.*.replies.content.attachments.document.urlExpirationDate',
                        },
                        { path: 'commentReplies.*.replies.draftContent.commentDate' },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.metadata.createdTimestamp',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.metadata.updatedTimestamp',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.attachments.image.urlExpirationDate',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.attachments.video.urlExpirationDate',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.attachments.video.posters.urlExpirationDate',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.attachments.audio.urlExpirationDate',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.attachments.document.urlExpirationDate',
                        },
                    ],
                },
                {
                    transformFn: float_2.transformRESTFloatToSDKFloat,
                    paths: [
                        {
                            path: 'comments.content.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'comments.content.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'comments.content.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'comments.content.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.audioData.coverImage.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.audioData.coverImage.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.audioData.coverImage.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.audioData.coverImage.duration',
                        },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __listCommentsByResource;
}
exports.listCommentsByResource = listCommentsByResource;
/**
 * Returns a thread of a comment or a reply.
 *
 * If you request a comment thread, the method returns a single comment with cursors. With cursors (`pagingMetadata.cursors.next` or `pagingMetadata.cursors.prev`) you can load replies by calling the List Comments by Resource method.
 *
 * If you request a reply thread, the method returns a reply with its parent comment. With cursors (`pagingMetadata.cursors.next` or `pagingMetadata.cursors.prev`) you can load replies by calling the List Comments by Resource method.
 */
function getCommentThread(payload) {
    function __getCommentThread({ host }) {
        const metadata = {
            entityFqdn: 'wix.comments.v2.comment',
            method: 'GET',
            methodFqn: 'wix.comments.ng.v1.CommentsNg.GetCommentThread',
            packageName: PACKAGE_NAME,
            url: resolveWixCommentsNgV1CommentsNgUrl({
                protoPath: '/v1/comments/{commentId}/thread',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'comments.createdDate' },
                        { path: 'comments.updatedDate' },
                        { path: 'comments.commentDate' },
                        { path: 'comments.content.commentDate' },
                        {
                            path: 'comments.content.richContent.metadata.createdTimestamp',
                        },
                        {
                            path: 'comments.content.richContent.metadata.updatedTimestamp',
                        },
                        { path: 'comments.content.attachments.image.urlExpirationDate' },
                        { path: 'comments.content.attachments.video.urlExpirationDate' },
                        {
                            path: 'comments.content.attachments.video.posters.urlExpirationDate',
                        },
                        { path: 'comments.content.attachments.audio.urlExpirationDate' },
                        {
                            path: 'comments.content.attachments.document.urlExpirationDate',
                        },
                        { path: 'comments.draftContent.commentDate' },
                        {
                            path: 'comments.draftContent.richContent.metadata.createdTimestamp',
                        },
                        {
                            path: 'comments.draftContent.richContent.metadata.updatedTimestamp',
                        },
                        {
                            path: 'comments.draftContent.attachments.image.urlExpirationDate',
                        },
                        {
                            path: 'comments.draftContent.attachments.video.urlExpirationDate',
                        },
                        {
                            path: 'comments.draftContent.attachments.video.posters.urlExpirationDate',
                        },
                        {
                            path: 'comments.draftContent.attachments.audio.urlExpirationDate',
                        },
                        {
                            path: 'comments.draftContent.attachments.document.urlExpirationDate',
                        },
                        { path: 'commentReplies.*.replies.createdDate' },
                        { path: 'commentReplies.*.replies.updatedDate' },
                        { path: 'commentReplies.*.replies.commentDate' },
                        { path: 'commentReplies.*.replies.content.commentDate' },
                        {
                            path: 'commentReplies.*.replies.content.richContent.metadata.createdTimestamp',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.metadata.updatedTimestamp',
                        },
                        {
                            path: 'commentReplies.*.replies.content.attachments.image.urlExpirationDate',
                        },
                        {
                            path: 'commentReplies.*.replies.content.attachments.video.urlExpirationDate',
                        },
                        {
                            path: 'commentReplies.*.replies.content.attachments.video.posters.urlExpirationDate',
                        },
                        {
                            path: 'commentReplies.*.replies.content.attachments.audio.urlExpirationDate',
                        },
                        {
                            path: 'commentReplies.*.replies.content.attachments.document.urlExpirationDate',
                        },
                        { path: 'commentReplies.*.replies.draftContent.commentDate' },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.metadata.createdTimestamp',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.metadata.updatedTimestamp',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.attachments.image.urlExpirationDate',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.attachments.video.urlExpirationDate',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.attachments.video.posters.urlExpirationDate',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.attachments.audio.urlExpirationDate',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.attachments.document.urlExpirationDate',
                        },
                    ],
                },
                {
                    transformFn: float_2.transformRESTFloatToSDKFloat,
                    paths: [
                        {
                            path: 'comments.content.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'comments.content.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'comments.content.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'comments.content.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'comments.content.richContent.nodes.audioData.coverImage.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'comments.draftContent.richContent.nodes.audioData.coverImage.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.content.richContent.nodes.audioData.coverImage.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.galleryData.items.image.media.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.galleryData.items.video.media.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.galleryData.options.item.ratio',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.imageData.image.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.mapData.mapSettings.lat',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.mapData.mapSettings.lng',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.pollData.poll.image.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.pollData.poll.options.image.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.pollData.design.poll.background.image.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.appEmbedData.image.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.videoData.video.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.videoData.thumbnail.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.audioData.audio.duration',
                        },
                        {
                            path: 'commentReplies.*.replies.draftContent.richContent.nodes.audioData.coverImage.duration',
                        },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __getCommentThread;
}
exports.getCommentThread = getCommentThread;
/** Publishes multiple comments with the `HIDDEN` status. The comment status becomes `PUBLISHED`. */
function bulkPublishComment(payload) {
    function __bulkPublishComment({ host }) {
        const metadata = {
            entityFqdn: 'wix.comments.v2.comment',
            method: 'POST',
            methodFqn: 'wix.comments.ng.v1.CommentsNg.BulkPublishComment',
            packageName: PACKAGE_NAME,
            url: resolveWixCommentsNgV1CommentsNgUrl({
                protoPath: '/v1/bulk/comments/publish-by-filter',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __bulkPublishComment;
}
exports.bulkPublishComment = bulkPublishComment;
/** Hides multiple comments. The comment status becomes `HIDDEN`. */
function bulkHideComment(payload) {
    function __bulkHideComment({ host }) {
        const metadata = {
            entityFqdn: 'wix.comments.v2.comment',
            method: 'PUT',
            methodFqn: 'wix.comments.ng.v1.CommentsNg.BulkHideComment',
            packageName: PACKAGE_NAME,
            url: resolveWixCommentsNgV1CommentsNgUrl({
                protoPath: '/v1/bulk/comments/hide-by-filter',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __bulkHideComment;
}
exports.bulkHideComment = bulkHideComment;
/** Deletes multiple comments. */
function bulkDeleteComment(payload) {
    function __bulkDeleteComment({ host }) {
        const metadata = {
            entityFqdn: 'wix.comments.v2.comment',
            method: 'PUT',
            methodFqn: 'wix.comments.ng.v1.CommentsNg.BulkDeleteComment',
            packageName: PACKAGE_NAME,
            url: resolveWixCommentsNgV1CommentsNgUrl({
                protoPath: '/v1/bulk/comments/delete-by-filter',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __bulkDeleteComment;
}
exports.bulkDeleteComment = bulkDeleteComment;
/** Moderates the draft content of multiple comments. */
function bulkModerateDraftContent(payload) {
    function __bulkModerateDraftContent({ host }) {
        const metadata = {
            entityFqdn: 'wix.comments.v2.comment',
            method: 'POST',
            methodFqn: 'wix.comments.ng.v1.CommentsNg.BulkModerateDraftContent',
            packageName: PACKAGE_NAME,
            url: resolveWixCommentsNgV1CommentsNgUrl({
                protoPath: '/v1/bulk/comments/moderate-by-filter',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __bulkModerateDraftContent;
}
exports.bulkModerateDraftContent = bulkModerateDraftContent;
/** Moves multiple comments to another resource. */
function bulkMoveCommentByFilter(payload) {
    function __bulkMoveCommentByFilter({ host }) {
        const metadata = {
            entityFqdn: 'wix.comments.v2.comment',
            method: 'PUT',
            methodFqn: 'wix.comments.ng.v1.CommentsNg.BulkMoveCommentByFilter',
            packageName: PACKAGE_NAME,
            url: resolveWixCommentsNgV1CommentsNgUrl({
                protoPath: '/v1/bulk/comments/move-by-filter',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __bulkMoveCommentByFilter;
}
exports.bulkMoveCommentByFilter = bulkMoveCommentByFilter;
//# sourceMappingURL=comments-v2-comment-comments.http.js.map