import { renameKeysFromRESTResponseToSDKResponse } from '@wix/sdk-runtime/rename-all-nested-keys';
import { transformRESTAudioToSDKAudio } from '@wix/sdk-runtime/transformations/audio';
import { transformRESTDocumentToSDKDocument } from '@wix/sdk-runtime/transformations/document';
import { transformRESTFloatToSDKFloat } from '@wix/sdk-runtime/transformations/float';
import { transformRESTImageToSDKImage } from '@wix/sdk-runtime/transformations/image';
import { transformRESTTimestampToSDKTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { transformRESTVideoV2ToSDKVideoV2 } from '@wix/sdk-runtime/transformations/video-v2';
import { EventDefinition } from '@wix/sdk-types';
import { bulkDeleteComment as universalBulkDeleteComment, bulkHideComment as universalBulkHideComment, bulkModerateDraftContent as universalBulkModerateDraftContent, bulkMoveCommentByFilter as universalBulkMoveCommentByFilter, bulkPublishComment as universalBulkPublishComment, countComments as universalCountComments, createComment as universalCreateComment, deleteComment as universalDeleteComment, getComment as universalGetComment, getCommentThread as universalGetCommentThread, hideComment as universalHideComment, listCommentsByResource as universalListCommentsByResource, markComment as universalMarkComment, moderateDraftContent as universalModerateDraftContent, publishComment as universalPublishComment, queryComments as universalQueryComments, unmarkComment as universalUnmarkComment, updateComment as universalUpdateComment, } from './comments-v2-comment-comments.universal.js';
export const __metadata = { PACKAGE_NAME: '@wix/comments' };
export function createComment(httpClient) {
    return (comment) => universalCreateComment(comment, 
    // @ts-ignore
    { httpClient });
}
export function getComment(httpClient) {
    return (commentId) => universalGetComment(commentId, 
    // @ts-ignore
    { httpClient });
}
export function updateComment(httpClient) {
    return (_id, comment) => universalUpdateComment(_id, comment, 
    // @ts-ignore
    { httpClient });
}
export function deleteComment(httpClient) {
    return (commentId) => universalDeleteComment(commentId, 
    // @ts-ignore
    { httpClient });
}
export function moderateDraftContent(httpClient) {
    return (commentId, revision, options) => universalModerateDraftContent(commentId, revision, options, 
    // @ts-ignore
    { httpClient });
}
export function queryComments(httpClient) {
    return (appId) => universalQueryComments(appId, 
    // @ts-ignore
    { httpClient });
}
export function markComment(httpClient) {
    return (commentId) => universalMarkComment(commentId, 
    // @ts-ignore
    { httpClient });
}
export function unmarkComment(httpClient) {
    return (commentId) => universalUnmarkComment(commentId, 
    // @ts-ignore
    { httpClient });
}
export function hideComment(httpClient) {
    return (commentId) => universalHideComment(commentId, 
    // @ts-ignore
    { httpClient });
}
export function publishComment(httpClient) {
    return (commentId) => universalPublishComment(commentId, 
    // @ts-ignore
    { httpClient });
}
export function countComments(httpClient) {
    return (appId, options) => universalCountComments(appId, options, 
    // @ts-ignore
    { httpClient });
}
export function listCommentsByResource(httpClient) {
    return (appId, options) => universalListCommentsByResource(appId, options, 
    // @ts-ignore
    { httpClient });
}
export function getCommentThread(httpClient) {
    return (commentId, options) => universalGetCommentThread(commentId, options, 
    // @ts-ignore
    { httpClient });
}
export function bulkPublishComment(httpClient) {
    return (appId, options) => universalBulkPublishComment(appId, options, 
    // @ts-ignore
    { httpClient });
}
export function bulkHideComment(httpClient) {
    return (appId, options) => universalBulkHideComment(appId, options, 
    // @ts-ignore
    { httpClient });
}
export function bulkDeleteComment(httpClient) {
    return (appId, options) => universalBulkDeleteComment(appId, options, 
    // @ts-ignore
    { httpClient });
}
export function bulkModerateDraftContent(httpClient) {
    return (appId, options) => universalBulkModerateDraftContent(appId, options, 
    // @ts-ignore
    { httpClient });
}
export function bulkMoveCommentByFilter(httpClient) {
    return (appId, options) => universalBulkMoveCommentByFilter(appId, options, 
    // @ts-ignore
    { httpClient });
}
export const onCommentContentChanged = EventDefinition('wix.comments.v2.comment_comment_content_changed', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'data.previousContent.commentDate' },
            {
                path: 'data.previousContent.richContent.metadata.createdTimestamp',
            },
            {
                path: 'data.previousContent.richContent.metadata.updatedTimestamp',
            },
            { path: 'data.currentContent.commentDate' },
            {
                path: 'data.currentContent.richContent.metadata.createdTimestamp',
            },
            {
                path: 'data.currentContent.richContent.metadata.updatedTimestamp',
            },
            { path: 'metadata.eventTime' },
        ],
    },
    {
        transformFn: transformRESTFloatToSDKFloat,
        paths: [
            {
                path: 'data.previousContent.richContent.nodes.galleryData.items.image.media.duration',
            },
            {
                path: 'data.previousContent.richContent.nodes.galleryData.items.video.media.duration',
            },
            {
                path: 'data.previousContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
            },
            {
                path: 'data.previousContent.richContent.nodes.galleryData.options.item.ratio',
            },
            {
                path: 'data.previousContent.richContent.nodes.imageData.image.duration',
            },
            {
                path: 'data.previousContent.richContent.nodes.mapData.mapSettings.lat',
            },
            {
                path: 'data.previousContent.richContent.nodes.mapData.mapSettings.lng',
            },
            {
                path: 'data.previousContent.richContent.nodes.pollData.poll.image.duration',
            },
            {
                path: 'data.previousContent.richContent.nodes.pollData.poll.options.image.duration',
            },
            {
                path: 'data.previousContent.richContent.nodes.pollData.design.poll.background.image.duration',
            },
            {
                path: 'data.previousContent.richContent.nodes.appEmbedData.image.duration',
            },
            {
                path: 'data.previousContent.richContent.nodes.videoData.video.duration',
            },
            {
                path: 'data.previousContent.richContent.nodes.videoData.thumbnail.duration',
            },
            {
                path: 'data.previousContent.richContent.nodes.audioData.audio.duration',
            },
            {
                path: 'data.previousContent.richContent.nodes.audioData.coverImage.duration',
            },
            {
                path: 'data.currentContent.richContent.nodes.galleryData.items.image.media.duration',
            },
            {
                path: 'data.currentContent.richContent.nodes.galleryData.items.video.media.duration',
            },
            {
                path: 'data.currentContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
            },
            {
                path: 'data.currentContent.richContent.nodes.galleryData.options.item.ratio',
            },
            {
                path: 'data.currentContent.richContent.nodes.imageData.image.duration',
            },
            {
                path: 'data.currentContent.richContent.nodes.mapData.mapSettings.lat',
            },
            {
                path: 'data.currentContent.richContent.nodes.mapData.mapSettings.lng',
            },
            {
                path: 'data.currentContent.richContent.nodes.pollData.poll.image.duration',
            },
            {
                path: 'data.currentContent.richContent.nodes.pollData.poll.options.image.duration',
            },
            {
                path: 'data.currentContent.richContent.nodes.pollData.design.poll.background.image.duration',
            },
            {
                path: 'data.currentContent.richContent.nodes.appEmbedData.image.duration',
            },
            {
                path: 'data.currentContent.richContent.nodes.videoData.video.duration',
            },
            {
                path: 'data.currentContent.richContent.nodes.videoData.thumbnail.duration',
            },
            {
                path: 'data.currentContent.richContent.nodes.audioData.audio.duration',
            },
            {
                path: 'data.currentContent.richContent.nodes.audioData.coverImage.duration',
            },
        ],
    },
    {
        transformFn: transformRESTImageToSDKImage,
        paths: [
            { path: 'data.previousContent.attachments.image' },
            { path: 'data.currentContent.attachments.image' },
        ],
    },
    {
        transformFn: transformRESTVideoV2ToSDKVideoV2,
        paths: [
            { path: 'data.previousContent.attachments.video' },
            { path: 'data.currentContent.attachments.video' },
        ],
    },
    {
        transformFn: transformRESTAudioToSDKAudio,
        paths: [
            { path: 'data.previousContent.attachments.audio' },
            { path: 'data.currentContent.attachments.audio' },
        ],
    },
    {
        transformFn: transformRESTDocumentToSDKDocument,
        paths: [
            { path: 'data.previousContent.attachments.document' },
            { path: 'data.currentContent.attachments.document' },
        ],
    },
])))();
export const onCommentHidden = EventDefinition('wix.comments.v2.comment_comment_hidden', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'data.comment.createdDate' },
            { path: 'data.comment.updatedDate' },
            { path: 'data.comment.commentDate' },
            { path: 'data.comment.content.commentDate' },
            {
                path: 'data.comment.content.richContent.metadata.createdTimestamp',
            },
            {
                path: 'data.comment.content.richContent.metadata.updatedTimestamp',
            },
            { path: 'data.comment.draftContent.commentDate' },
            {
                path: 'data.comment.draftContent.richContent.metadata.createdTimestamp',
            },
            {
                path: 'data.comment.draftContent.richContent.metadata.updatedTimestamp',
            },
            { path: 'metadata.eventTime' },
        ],
    },
    {
        transformFn: transformRESTFloatToSDKFloat,
        paths: [
            {
                path: 'data.comment.content.richContent.nodes.galleryData.items.image.media.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.galleryData.items.video.media.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.galleryData.options.item.ratio',
            },
            {
                path: 'data.comment.content.richContent.nodes.imageData.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.mapData.mapSettings.lat',
            },
            {
                path: 'data.comment.content.richContent.nodes.mapData.mapSettings.lng',
            },
            {
                path: 'data.comment.content.richContent.nodes.pollData.poll.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.pollData.poll.options.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.pollData.design.poll.background.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.appEmbedData.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.videoData.video.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.videoData.thumbnail.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.audioData.audio.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.audioData.coverImage.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.galleryData.items.image.media.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.galleryData.items.video.media.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.galleryData.options.item.ratio',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.imageData.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.mapData.mapSettings.lat',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.mapData.mapSettings.lng',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.pollData.poll.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.pollData.poll.options.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.appEmbedData.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.videoData.video.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.videoData.thumbnail.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.audioData.audio.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.audioData.coverImage.duration',
            },
        ],
    },
    {
        transformFn: transformRESTImageToSDKImage,
        paths: [
            { path: 'data.comment.content.attachments.image' },
            { path: 'data.comment.draftContent.attachments.image' },
        ],
    },
    {
        transformFn: transformRESTVideoV2ToSDKVideoV2,
        paths: [
            { path: 'data.comment.content.attachments.video' },
            { path: 'data.comment.draftContent.attachments.video' },
        ],
    },
    {
        transformFn: transformRESTAudioToSDKAudio,
        paths: [
            { path: 'data.comment.content.attachments.audio' },
            { path: 'data.comment.draftContent.attachments.audio' },
        ],
    },
    {
        transformFn: transformRESTDocumentToSDKDocument,
        paths: [
            { path: 'data.comment.content.attachments.document' },
            { path: 'data.comment.draftContent.attachments.document' },
        ],
    },
])))();
export const onCommentMarked = EventDefinition('wix.comments.v2.comment_comment_marked', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'data.comment.createdDate' },
            { path: 'data.comment.updatedDate' },
            { path: 'data.comment.commentDate' },
            { path: 'data.comment.content.commentDate' },
            {
                path: 'data.comment.content.richContent.metadata.createdTimestamp',
            },
            {
                path: 'data.comment.content.richContent.metadata.updatedTimestamp',
            },
            { path: 'data.comment.draftContent.commentDate' },
            {
                path: 'data.comment.draftContent.richContent.metadata.createdTimestamp',
            },
            {
                path: 'data.comment.draftContent.richContent.metadata.updatedTimestamp',
            },
            { path: 'metadata.eventTime' },
        ],
    },
    {
        transformFn: transformRESTFloatToSDKFloat,
        paths: [
            {
                path: 'data.comment.content.richContent.nodes.galleryData.items.image.media.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.galleryData.items.video.media.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.galleryData.options.item.ratio',
            },
            {
                path: 'data.comment.content.richContent.nodes.imageData.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.mapData.mapSettings.lat',
            },
            {
                path: 'data.comment.content.richContent.nodes.mapData.mapSettings.lng',
            },
            {
                path: 'data.comment.content.richContent.nodes.pollData.poll.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.pollData.poll.options.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.pollData.design.poll.background.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.appEmbedData.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.videoData.video.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.videoData.thumbnail.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.audioData.audio.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.audioData.coverImage.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.galleryData.items.image.media.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.galleryData.items.video.media.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.galleryData.options.item.ratio',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.imageData.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.mapData.mapSettings.lat',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.mapData.mapSettings.lng',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.pollData.poll.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.pollData.poll.options.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.appEmbedData.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.videoData.video.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.videoData.thumbnail.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.audioData.audio.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.audioData.coverImage.duration',
            },
        ],
    },
    {
        transformFn: transformRESTImageToSDKImage,
        paths: [
            { path: 'data.comment.content.attachments.image' },
            { path: 'data.comment.draftContent.attachments.image' },
        ],
    },
    {
        transformFn: transformRESTVideoV2ToSDKVideoV2,
        paths: [
            { path: 'data.comment.content.attachments.video' },
            { path: 'data.comment.draftContent.attachments.video' },
        ],
    },
    {
        transformFn: transformRESTAudioToSDKAudio,
        paths: [
            { path: 'data.comment.content.attachments.audio' },
            { path: 'data.comment.draftContent.attachments.audio' },
        ],
    },
    {
        transformFn: transformRESTDocumentToSDKDocument,
        paths: [
            { path: 'data.comment.content.attachments.document' },
            { path: 'data.comment.draftContent.attachments.document' },
        ],
    },
])))();
export const onCommentMoved = EventDefinition('wix.comments.v2.comment_comment_moved', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'data.comment.createdDate' },
            { path: 'data.comment.updatedDate' },
            { path: 'data.comment.commentDate' },
            { path: 'data.comment.content.commentDate' },
            {
                path: 'data.comment.content.richContent.metadata.createdTimestamp',
            },
            {
                path: 'data.comment.content.richContent.metadata.updatedTimestamp',
            },
            { path: 'data.comment.draftContent.commentDate' },
            {
                path: 'data.comment.draftContent.richContent.metadata.createdTimestamp',
            },
            {
                path: 'data.comment.draftContent.richContent.metadata.updatedTimestamp',
            },
            { path: 'metadata.eventTime' },
        ],
    },
    {
        transformFn: transformRESTFloatToSDKFloat,
        paths: [
            {
                path: 'data.comment.content.richContent.nodes.galleryData.items.image.media.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.galleryData.items.video.media.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.galleryData.options.item.ratio',
            },
            {
                path: 'data.comment.content.richContent.nodes.imageData.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.mapData.mapSettings.lat',
            },
            {
                path: 'data.comment.content.richContent.nodes.mapData.mapSettings.lng',
            },
            {
                path: 'data.comment.content.richContent.nodes.pollData.poll.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.pollData.poll.options.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.pollData.design.poll.background.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.appEmbedData.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.videoData.video.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.videoData.thumbnail.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.audioData.audio.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.audioData.coverImage.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.galleryData.items.image.media.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.galleryData.items.video.media.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.galleryData.options.item.ratio',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.imageData.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.mapData.mapSettings.lat',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.mapData.mapSettings.lng',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.pollData.poll.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.pollData.poll.options.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.appEmbedData.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.videoData.video.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.videoData.thumbnail.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.audioData.audio.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.audioData.coverImage.duration',
            },
        ],
    },
    {
        transformFn: transformRESTImageToSDKImage,
        paths: [
            { path: 'data.comment.content.attachments.image' },
            { path: 'data.comment.draftContent.attachments.image' },
        ],
    },
    {
        transformFn: transformRESTVideoV2ToSDKVideoV2,
        paths: [
            { path: 'data.comment.content.attachments.video' },
            { path: 'data.comment.draftContent.attachments.video' },
        ],
    },
    {
        transformFn: transformRESTAudioToSDKAudio,
        paths: [
            { path: 'data.comment.content.attachments.audio' },
            { path: 'data.comment.draftContent.attachments.audio' },
        ],
    },
    {
        transformFn: transformRESTDocumentToSDKDocument,
        paths: [
            { path: 'data.comment.content.attachments.document' },
            { path: 'data.comment.draftContent.attachments.document' },
        ],
    },
])))();
export const onCommentPublished = EventDefinition('wix.comments.v2.comment_comment_published', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'data.comment.createdDate' },
            { path: 'data.comment.updatedDate' },
            { path: 'data.comment.commentDate' },
            { path: 'data.comment.content.commentDate' },
            {
                path: 'data.comment.content.richContent.metadata.createdTimestamp',
            },
            {
                path: 'data.comment.content.richContent.metadata.updatedTimestamp',
            },
            { path: 'data.comment.draftContent.commentDate' },
            {
                path: 'data.comment.draftContent.richContent.metadata.createdTimestamp',
            },
            {
                path: 'data.comment.draftContent.richContent.metadata.updatedTimestamp',
            },
            { path: 'metadata.eventTime' },
        ],
    },
    {
        transformFn: transformRESTFloatToSDKFloat,
        paths: [
            {
                path: 'data.comment.content.richContent.nodes.galleryData.items.image.media.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.galleryData.items.video.media.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.galleryData.options.item.ratio',
            },
            {
                path: 'data.comment.content.richContent.nodes.imageData.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.mapData.mapSettings.lat',
            },
            {
                path: 'data.comment.content.richContent.nodes.mapData.mapSettings.lng',
            },
            {
                path: 'data.comment.content.richContent.nodes.pollData.poll.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.pollData.poll.options.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.pollData.design.poll.background.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.appEmbedData.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.videoData.video.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.videoData.thumbnail.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.audioData.audio.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.audioData.coverImage.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.galleryData.items.image.media.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.galleryData.items.video.media.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.galleryData.options.item.ratio',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.imageData.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.mapData.mapSettings.lat',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.mapData.mapSettings.lng',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.pollData.poll.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.pollData.poll.options.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.appEmbedData.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.videoData.video.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.videoData.thumbnail.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.audioData.audio.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.audioData.coverImage.duration',
            },
        ],
    },
    {
        transformFn: transformRESTImageToSDKImage,
        paths: [
            { path: 'data.comment.content.attachments.image' },
            { path: 'data.comment.draftContent.attachments.image' },
        ],
    },
    {
        transformFn: transformRESTVideoV2ToSDKVideoV2,
        paths: [
            { path: 'data.comment.content.attachments.video' },
            { path: 'data.comment.draftContent.attachments.video' },
        ],
    },
    {
        transformFn: transformRESTAudioToSDKAudio,
        paths: [
            { path: 'data.comment.content.attachments.audio' },
            { path: 'data.comment.draftContent.attachments.audio' },
        ],
    },
    {
        transformFn: transformRESTDocumentToSDKDocument,
        paths: [
            { path: 'data.comment.content.attachments.document' },
            { path: 'data.comment.draftContent.attachments.document' },
        ],
    },
])))();
export const onCommentUnmarked = EventDefinition('wix.comments.v2.comment_comment_unmarked', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'data.comment.createdDate' },
            { path: 'data.comment.updatedDate' },
            { path: 'data.comment.commentDate' },
            { path: 'data.comment.content.commentDate' },
            {
                path: 'data.comment.content.richContent.metadata.createdTimestamp',
            },
            {
                path: 'data.comment.content.richContent.metadata.updatedTimestamp',
            },
            { path: 'data.comment.draftContent.commentDate' },
            {
                path: 'data.comment.draftContent.richContent.metadata.createdTimestamp',
            },
            {
                path: 'data.comment.draftContent.richContent.metadata.updatedTimestamp',
            },
            { path: 'metadata.eventTime' },
        ],
    },
    {
        transformFn: transformRESTFloatToSDKFloat,
        paths: [
            {
                path: 'data.comment.content.richContent.nodes.galleryData.items.image.media.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.galleryData.items.video.media.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.galleryData.options.item.ratio',
            },
            {
                path: 'data.comment.content.richContent.nodes.imageData.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.mapData.mapSettings.lat',
            },
            {
                path: 'data.comment.content.richContent.nodes.mapData.mapSettings.lng',
            },
            {
                path: 'data.comment.content.richContent.nodes.pollData.poll.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.pollData.poll.options.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.pollData.design.poll.background.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.appEmbedData.image.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.videoData.video.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.videoData.thumbnail.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.audioData.audio.duration',
            },
            {
                path: 'data.comment.content.richContent.nodes.audioData.coverImage.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.galleryData.items.image.media.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.galleryData.items.video.media.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.galleryData.options.item.ratio',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.imageData.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.mapData.mapSettings.lat',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.mapData.mapSettings.lng',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.pollData.poll.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.pollData.poll.options.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.appEmbedData.image.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.videoData.video.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.videoData.thumbnail.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.audioData.audio.duration',
            },
            {
                path: 'data.comment.draftContent.richContent.nodes.audioData.coverImage.duration',
            },
        ],
    },
    {
        transformFn: transformRESTImageToSDKImage,
        paths: [
            { path: 'data.comment.content.attachments.image' },
            { path: 'data.comment.draftContent.attachments.image' },
        ],
    },
    {
        transformFn: transformRESTVideoV2ToSDKVideoV2,
        paths: [
            { path: 'data.comment.content.attachments.video' },
            { path: 'data.comment.draftContent.attachments.video' },
        ],
    },
    {
        transformFn: transformRESTAudioToSDKAudio,
        paths: [
            { path: 'data.comment.content.attachments.audio' },
            { path: 'data.comment.draftContent.attachments.audio' },
        ],
    },
    {
        transformFn: transformRESTDocumentToSDKDocument,
        paths: [
            { path: 'data.comment.content.attachments.document' },
            { path: 'data.comment.draftContent.attachments.document' },
        ],
    },
])))();
export const onCommentCreated = EventDefinition('wix.comments.v2.comment_created', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'entity.createdDate' },
            { path: 'entity.updatedDate' },
            { path: 'entity.commentDate' },
            { path: 'entity.content.commentDate' },
            { path: 'entity.content.richContent.metadata.createdTimestamp' },
            { path: 'entity.content.richContent.metadata.updatedTimestamp' },
            { path: 'entity.draftContent.commentDate' },
            {
                path: 'entity.draftContent.richContent.metadata.createdTimestamp',
            },
            {
                path: 'entity.draftContent.richContent.metadata.updatedTimestamp',
            },
            { path: 'metadata.eventTime' },
        ],
    },
    {
        transformFn: transformRESTFloatToSDKFloat,
        paths: [
            {
                path: 'entity.content.richContent.nodes.galleryData.items.image.media.duration',
            },
            {
                path: 'entity.content.richContent.nodes.galleryData.items.video.media.duration',
            },
            {
                path: 'entity.content.richContent.nodes.galleryData.items.video.thumbnail.duration',
            },
            {
                path: 'entity.content.richContent.nodes.galleryData.options.item.ratio',
            },
            {
                path: 'entity.content.richContent.nodes.imageData.image.duration',
            },
            {
                path: 'entity.content.richContent.nodes.mapData.mapSettings.lat',
            },
            {
                path: 'entity.content.richContent.nodes.mapData.mapSettings.lng',
            },
            {
                path: 'entity.content.richContent.nodes.pollData.poll.image.duration',
            },
            {
                path: 'entity.content.richContent.nodes.pollData.poll.options.image.duration',
            },
            {
                path: 'entity.content.richContent.nodes.pollData.design.poll.background.image.duration',
            },
            {
                path: 'entity.content.richContent.nodes.appEmbedData.image.duration',
            },
            {
                path: 'entity.content.richContent.nodes.videoData.video.duration',
            },
            {
                path: 'entity.content.richContent.nodes.videoData.thumbnail.duration',
            },
            {
                path: 'entity.content.richContent.nodes.audioData.audio.duration',
            },
            {
                path: 'entity.content.richContent.nodes.audioData.coverImage.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.galleryData.items.image.media.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.galleryData.items.video.media.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.galleryData.options.item.ratio',
            },
            {
                path: 'entity.draftContent.richContent.nodes.imageData.image.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.mapData.mapSettings.lat',
            },
            {
                path: 'entity.draftContent.richContent.nodes.mapData.mapSettings.lng',
            },
            {
                path: 'entity.draftContent.richContent.nodes.pollData.poll.image.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.pollData.poll.options.image.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.pollData.design.poll.background.image.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.appEmbedData.image.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.videoData.video.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.videoData.thumbnail.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.audioData.audio.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.audioData.coverImage.duration',
            },
        ],
    },
    {
        transformFn: transformRESTImageToSDKImage,
        paths: [
            { path: 'entity.content.attachments.image' },
            { path: 'entity.draftContent.attachments.image' },
        ],
    },
    {
        transformFn: transformRESTVideoV2ToSDKVideoV2,
        paths: [
            { path: 'entity.content.attachments.video' },
            { path: 'entity.draftContent.attachments.video' },
        ],
    },
    {
        transformFn: transformRESTAudioToSDKAudio,
        paths: [
            { path: 'entity.content.attachments.audio' },
            { path: 'entity.draftContent.attachments.audio' },
        ],
    },
    {
        transformFn: transformRESTDocumentToSDKDocument,
        paths: [
            { path: 'entity.content.attachments.document' },
            { path: 'entity.draftContent.attachments.document' },
        ],
    },
])))();
export const onCommentResourceCommentCountChanged = EventDefinition('wix.comments.v2.comment_resource_comment_count_changed', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [{ path: 'metadata.eventTime' }],
    },
])))();
export const onCommentUpdated = EventDefinition('wix.comments.v2.comment_updated', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'entity.createdDate' },
            { path: 'entity.updatedDate' },
            { path: 'entity.commentDate' },
            { path: 'entity.content.commentDate' },
            { path: 'entity.content.richContent.metadata.createdTimestamp' },
            { path: 'entity.content.richContent.metadata.updatedTimestamp' },
            { path: 'entity.draftContent.commentDate' },
            {
                path: 'entity.draftContent.richContent.metadata.createdTimestamp',
            },
            {
                path: 'entity.draftContent.richContent.metadata.updatedTimestamp',
            },
            { path: 'metadata.eventTime' },
        ],
    },
    {
        transformFn: transformRESTFloatToSDKFloat,
        paths: [
            {
                path: 'entity.content.richContent.nodes.galleryData.items.image.media.duration',
            },
            {
                path: 'entity.content.richContent.nodes.galleryData.items.video.media.duration',
            },
            {
                path: 'entity.content.richContent.nodes.galleryData.items.video.thumbnail.duration',
            },
            {
                path: 'entity.content.richContent.nodes.galleryData.options.item.ratio',
            },
            {
                path: 'entity.content.richContent.nodes.imageData.image.duration',
            },
            {
                path: 'entity.content.richContent.nodes.mapData.mapSettings.lat',
            },
            {
                path: 'entity.content.richContent.nodes.mapData.mapSettings.lng',
            },
            {
                path: 'entity.content.richContent.nodes.pollData.poll.image.duration',
            },
            {
                path: 'entity.content.richContent.nodes.pollData.poll.options.image.duration',
            },
            {
                path: 'entity.content.richContent.nodes.pollData.design.poll.background.image.duration',
            },
            {
                path: 'entity.content.richContent.nodes.appEmbedData.image.duration',
            },
            {
                path: 'entity.content.richContent.nodes.videoData.video.duration',
            },
            {
                path: 'entity.content.richContent.nodes.videoData.thumbnail.duration',
            },
            {
                path: 'entity.content.richContent.nodes.audioData.audio.duration',
            },
            {
                path: 'entity.content.richContent.nodes.audioData.coverImage.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.galleryData.items.image.media.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.galleryData.items.video.media.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.galleryData.options.item.ratio',
            },
            {
                path: 'entity.draftContent.richContent.nodes.imageData.image.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.mapData.mapSettings.lat',
            },
            {
                path: 'entity.draftContent.richContent.nodes.mapData.mapSettings.lng',
            },
            {
                path: 'entity.draftContent.richContent.nodes.pollData.poll.image.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.pollData.poll.options.image.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.pollData.design.poll.background.image.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.appEmbedData.image.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.videoData.video.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.videoData.thumbnail.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.audioData.audio.duration',
            },
            {
                path: 'entity.draftContent.richContent.nodes.audioData.coverImage.duration',
            },
        ],
    },
    {
        transformFn: transformRESTImageToSDKImage,
        paths: [
            { path: 'entity.content.attachments.image' },
            { path: 'entity.draftContent.attachments.image' },
        ],
    },
    {
        transformFn: transformRESTVideoV2ToSDKVideoV2,
        paths: [
            { path: 'entity.content.attachments.video' },
            { path: 'entity.draftContent.attachments.video' },
        ],
    },
    {
        transformFn: transformRESTAudioToSDKAudio,
        paths: [
            { path: 'entity.content.attachments.audio' },
            { path: 'entity.draftContent.attachments.audio' },
        ],
    },
    {
        transformFn: transformRESTDocumentToSDKDocument,
        paths: [
            { path: 'entity.content.attachments.document' },
            { path: 'entity.draftContent.attachments.document' },
        ],
    },
])))();
export { Action, Alignment, AppType, BackgroundType, Crop, DecorationType, Direction, FontType, GIFType, InitialExpandedItems, LayoutType, LineStyle, MapType, NodeType, NullValue, Order, Orientation, PluginContainerDataAlignment, PollLayoutDirection, PollLayoutType, Position, ReplySortOrder, SortOrder, Source, Status, Target, TextAlignment, ThumbnailsAlignment, Type, VersioningMode, VerticalAlignment, ViewMode, ViewRole, VoteRole, WebhookIdentityType, Width, WidthType, } from './comments-v2-comment-comments.universal.js';
//# sourceMappingURL=comments-v2-comment-comments.public.js.map